import { getOssInfo } from '@/services/ant-design-pro/api';
import { getImgSizeProper } from '@/utils';
import { request } from '@umijs/max';
import { Avatar, message, Spin, Upload } from 'antd';
import { RcFile } from 'antd/lib/upload';
import React, { useState } from 'react';
import './index.less';

interface Props {
  mobile: string;
  defaultUrl: string;
  value?: string; // 图片地址
  onChange?: (data: string) => void;
}
const UploadAvatar: React.FC<Props> = (props) => {
  /** 变量START */
  const { mobile, defaultUrl, value, onChange } = props;
  const [imageFile, setImageFile] = useState<string>(value || '');
  const [loading, setLoading] = useState<boolean>(false);
  /** 变量END */

  const beforeUpload = async (file: RcFile) => {
    const isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';
    if (!isJpgOrPng) {
      message.error('您只能上传JPG/PNG文件！');
    }
    const isLt2M = file.size / 1024 / 1024 < 2;
    if (!isLt2M) {
      message.error('图像必须小于2MB！');
    }

    let imgData: any = await getImgSizeProper(file);
    if (imgData.width < 50 || imgData.width > 600 || imgData.height < 50 || imgData.height > 600) {
      message.error(`请传入图片长宽在50-600`);
      return false;
    } else if (imgData.width !== imgData.height) {
      message.error(`请传入正方形的图片`);
      return false;
    }
    return isJpgOrPng && isLt2M;
  };

  return (
    <Upload
      name="avatar"
      listType="picture-card"
      accept="image/gif,image/jpeg,image/png,image/jpg"
      className="uploaderAvatar"
      beforeUpload={beforeUpload}
      maxCount={1}
      disabled={loading}
      showUploadList={false}
      customRequest={(options: any) => {
        setLoading(true);
        getOssInfo({ type: 'image/jpeg', fileType: 'image' }).then(async (res) => {
          try {
            let formData = new FormData();
            Object.keys(res.data).forEach((key: string) => {
              if (key !== 'url') {
                formData.append(key, res.data[key]);
              }
            });
            formData.append('file', options.file);
            let urlData = await request(res?.data?.ossUrl, { method: 'POST', data: formData });
            setLoading(false);
            setImageFile(urlData?.data?.url);
            if (urlData?.data?.url) {
              onChange && onChange(urlData?.data?.url);
            }
          } catch (error) {
            setLoading(false);
          }
        });
      }}
    >
      <Spin spinning={loading}>
        <Avatar
          style={{ backgroundColor: '#7265e6', verticalAlign: 'middle' }}
          size={104}
          src={imageFile || defaultUrl}
        >
          {mobile}
        </Avatar>
      </Spin>
    </Upload>
  );
};

export default React.memo(UploadAvatar);
