import { getOssInfo } from '@/services/ant-design-pro/api';
import { CloudUploadOutlined, DeleteOutlined, PaperClipOutlined } from '@ant-design/icons';
import { request } from '@umijs/max';
import { Button, Flex, message, Space, Typography, Upload } from 'antd';
import { RcFile } from 'antd/lib/upload';
import React, { useState } from 'react';
import './index.less';

interface Props {
  value?: string; // 压缩包地址
  onChange?: (data: RcFile | string) => void;
  tooltip?: JSX.Element;
}
const UploadZip: React.FC<Props> = (props) => {
  /** 变量START */
  const { value, tooltip, onChange } = props;
  const [zipFile, setZipFile] = useState<string>(value || '');
  const [loading, setLoading] = useState<boolean>(false);
  /** 变量END */

  const beforeUpload = async (file: RcFile) => {
    const isZipOrRar =
      file.type === 'application/zip' ||
      file.type === 'application/x-zip-compressed' ||
      file.type === 'application/x-rar-compressed' ||
      file.type === 'application/x-gzip' ||
      file.type === 'application/x-7z-compressed' ||
      file.name.includes('.7z');
    if (!isZipOrRar) {
      message.error('您只能上传压缩包文件！');
    }
    // const isLt20M = file.size / 1024 / 1024 < 20;
    // if (!isLt20M) {
    //     message.error('压缩包必须小于20MB！');
    // }

    return isZipOrRar;
  };

  return (
    <div className="myUpload">
      <Space align="start">
        {zipFile && (
          <Flex style={{}} gap={10}>
            <PaperClipOutlined />
            <Typography.Text ellipsis style={{ maxWidth: 300 }}>
              {zipFile}
            </Typography.Text>
            <DeleteOutlined
              style={{ color: 'red' }}
              onClick={() => {
                setZipFile('');
                onChange?.('');
              }}
            />
          </Flex>
        )}
        <Upload
          name="avatar"
          accept=".zip, .rar, .7z, .gz, application/zip, application/x-zip-compressed, application/x-rar-compressed, application/x-7z-compressed, application/x-gzip"
          className="avatar-uploader"
          beforeUpload={beforeUpload}
          maxCount={1}
          showUploadList={false}
          customRequest={(options: any) => {
            setLoading(true);
            getOssInfo({ type: 'application/zip', fileType: 'zip' }).then(async (res) => {
              try {
                let formData = new FormData();
                Object.keys(res.data).forEach((key: string) => {
                  if (key !== 'url') {
                    formData.append(key, res.data[key]);
                  }
                });
                formData.append('file', options.file);
                let urlData = await request(res?.data?.ossUrl, { method: 'POST', data: formData });
                setLoading(false);
                setZipFile(urlData?.data?.url);
                if (urlData?.data?.url) {
                  onChange && onChange(urlData?.data?.url);
                }
              } catch (error) {
                setLoading(false);
              }
            });
          }}
        >
          {zipFile.length > 0 ? null : (
            <Button loading={loading} icon={<CloudUploadOutlined />} type="primary">
              上传文件
            </Button>
          )}
        </Upload>
        <div>{tooltip && tooltip}</div>
      </Space>
    </div>
  );
};

export default React.memo(UploadZip);
