import UploadAvatar from '@/components/UploadImg/UploadAvatar';
import { getCenterUserInfoApi, setUserInfoApi } from '@/services/task-api/center';
import { FieldTimeOutlined, PhoneOutlined } from '@ant-design/icons';
import { useModel } from '@umijs/max';
import { useRequest } from 'ahooks';
import { Col, Divider, message, Modal, Row, Statistic, Typography } from 'antd';
import React, { useState } from 'react';
import { flushSync } from 'react-dom';
import styles from './Center.less';
import { CurrentUser } from './data';

interface Props {
  visible?: boolean;
  onClose?: () => void;
}
/**
 * 弹窗个人中心
 * @returns
 */
const ModalCenter: React.FC<Props> = ({ visible, onClose }) => {
  /*******************************/
  const { initialState, setInitialState } = useModel('@@initialState');
  const { data, refresh } = useRequest(getCenterUserInfoApi);
  const [editing, setEditing] = useState<boolean>(false);
  const setUserInfo = useRequest(setUserInfoApi, { manual: true });
  /*******************************/

  const fetchUserInfo = async () => {
    const userInfo = await initialState?.fetchUserInfo?.();
    if (userInfo) {
      flushSync(() => {
        setInitialState((s) => ({
          ...s,
          currentUser: {
            avatar: `https://xsgames.co/randomusers/avatar.php?g=pixel&key=${Math.floor(
              Math.random() * 10,
            )}`,
            ...userInfo,
          },
        }));
      });
    }
  };

  //  渲染用户信息
  const renderUserInfo = ({ mobile, createTime }: Partial<CurrentUser>) => {
    return (
      <div className={styles.detail}>
        <p>
          <PhoneOutlined
            style={{
              marginRight: 8,
            }}
          />
          {mobile}
        </p>
        <p>
          <FieldTimeOutlined
            style={{
              marginRight: 8,
            }}
          />
          {createTime}
        </p>
      </div>
    );
  };

  return (
    <Modal
      title="个人中心"
      open={visible}
      onCancel={onClose}
      footer={null}
      style={{ maxWidth: 400 }}
    >
      <div>
        <div className={styles.avatarHolder}>
          <UploadAvatar
            defaultUrl={data?.data?.avatar || ''}
            mobile={data?.data?.mobile}
            value={data?.data?.avatar}
            onChange={(e) => {
              if (!e) {
                message.error('请选择头像！');
                return;
              }
              setUserInfo.runAsync({ avatar: e, userName: data?.data?.userName }).then((res) => {
                if (res.data) {
                  refresh();
                  fetchUserInfo();
                }
              });
            }}
          />
          <div className={styles.name} style={{ marginTop: 20 }}>
            <Typography.Text
              editable={{
                maxLength: 6,
                editing,
                onStart() {
                  setEditing(true);
                },
                onChange: (value) => {
                  if (!value) {
                    message.error('昵称不能为空！');
                    return;
                  }
                  if (value === data?.data?.userName) {
                    setEditing(false);
                    return;
                  }
                  setUserInfo
                    .runAsync({ avatar: data?.data?.avatar, userName: value })
                    .then((res) => {
                      if (res.data) {
                        setEditing(false);
                        refresh();
                        fetchUserInfo();
                      }
                    });
                },
              }}
              className={styles.name}
            >
              {data?.data?.userName}
            </Typography.Text>
          </div>
          <div>海纳百川，有容乃大</div>
        </div>
        {renderUserInfo(data?.data || {})}
        <Divider dashed />
        <Row gutter={[16, 16]}>
          <Col span={12}>
            <Statistic
              title="累计上传作品"
              value={
                data?.data?.materialCount
                  ? data?.data?.materialCount
                  : data?.data?.materialCount === 0
                  ? 0
                  : '--'
              }
              valueStyle={{ color: '#3f8600' }}
            />
          </Col>
          <Col span={12}>
            <Statistic
              title="全部收益"
              value={
                data?.data?.sumIncome
                  ? data?.data?.sumIncome
                  : data?.data?.sumIncome === 0
                  ? 0
                  : '--'
              }
              valueStyle={{ color: '#3f8600' }}
            />
          </Col>
          <Col span={12}>
            <Statistic
              title="已结算"
              value={
                data?.data?.settled ? data?.data?.settled : data?.data?.settled === 0 ? 0 : '--'
              }
              valueStyle={{ color: '#3f8600' }}
            />
          </Col>
          <Col span={12}>
            <Statistic
              title="当前收益"
              value={
                data?.data?.nowIncome
                  ? data?.data?.nowIncome
                  : data?.data?.nowIncome === 0
                  ? 0
                  : '--'
              }
              valueStyle={{ color: '#3f8600' }}
            />
          </Col>
        </Row>
      </div>
    </Modal>
  );
};

export default React.memo(ModalCenter);
