import { GridContent } from "@ant-design/pro-components";
import { useModel } from "@umijs/max";
import { Avatar, Card, Col, Divider, Row, Statistic, theme } from "antd"
import styles from './Center.less';
import { CurrentUser } from "./data";
import { FieldTimeOutlined, PhoneOutlined } from "@ant-design/icons";
import { useRequest } from "ahooks";
import { getCenterUserInfoApi } from "@/services/task-api/center";

const Center: React.FC = () => {

    /************************************/
    const { useToken } = theme;
    const { token } = useToken();
    const { initialState } = useModel('@@initialState');
    const { data } = useRequest(getCenterUserInfoApi)
    /************************************/

    //  渲染用户信息
    const renderUserInfo = ({ mobile, createTime }: Partial<CurrentUser>) => {
        return (
            <div className={styles.detail}>
                <p>
                    <PhoneOutlined
                        style={{
                            marginRight: 8,
                        }}
                    />
                    {mobile}
                </p>
                <p>
                    <FieldTimeOutlined
                        style={{
                            marginRight: 8,
                        }}
                    />
                    {createTime}
                </p>
            </div>
        );
    };

    return <GridContent>
        <Row gutter={24}>
            <Col lg={7} md={24}>
                <Card bordered={false} style={{ marginBottom: 24 }} >
                    <div>
                        <div className={styles.avatarHolder}>
                            <Avatar
                                style={{ backgroundColor: '#7265e6', verticalAlign: 'middle', marginBottom: 20 }}
                                size={104}
                                src={initialState?.currentUser?.avatar}
                            >{data?.data?.mobile}</Avatar>
                            <div className={styles.name}>{data?.data?.userName}</div>
                            <div>海纳百川，有容乃大</div>
                        </div>
                        {renderUserInfo(data?.data || {})}
                        <Divider dashed />
                        <Row gutter={[16, 16]}>
                            <Col span={12}>
                                <Statistic
                                    title="累计上传作品"
                                    value={data?.data?.materilaCount ? data?.data?.materilaCount : data?.data?.materilaCount === 0 ? 0 : '--'}
                                    valueStyle={{ color: '#3f8600' }}
                                />
                            </Col>
                            <Col span={12}>
                                <Statistic
                                    title="全部收益"
                                    value={data?.data?.sumIncome ? data?.data?.sumIncome : data?.data?.sumIncome === 0 ? 0 : '--'}
                                    valueStyle={{ color: '#3f8600' }}
                                />
                            </Col>
                            <Col span={12}>
                                <Statistic
                                    title="已结算"
                                    value={data?.data?.settled ? data?.data?.settled : data?.data?.settled === 0 ? 0 : '--'}
                                    valueStyle={{ color: '#3f8600' }}
                                />
                            </Col>
                            <Col span={12}>
                                <Statistic
                                    title="当前收益"
                                    value={data?.data?.nowIncome ? data?.data?.nowIncome : data?.data?.nowIncome === 0 ? 0 : '--'}
                                    valueStyle={{ color: '#3f8600' }}
                                />
                            </Col>
                        </Row>
                    </div>
                </Card>
            </Col>
            <Col lg={17} md={24}>
                
            </Col>
        </Row>
    </GridContent>
}

export default Center