import VideoNews from '@/components/VideoNews';
import { getOssInfo } from '@/services/ant-design-pro/api';
import { getMD5, videoMessage } from '@/utils';
import { InboxOutlined } from '@ant-design/icons';
import { request } from '@umijs/max';
import { message, Space, Spin, Upload } from 'antd';
import { RcFile } from 'antd/lib/upload';
import React, { useState } from 'react';
import './index.less';

interface Props {
  materialClaimJson: string;
  materialBeanList: TASKAPI.MaterialBean[];
  value?: TASKAPI.MaterialBean;
  onChange?: (value?: TASKAPI.MaterialBean) => void;
}
/**
 * 视频上传
 * @returns
 */
const Video: React.FC<Props> = ({ value, onChange, materialClaimJson, materialBeanList = [] }) => {
  /** 变量START */
  const [videoFile, setVideoFile] = useState<TASKAPI.MaterialBean | undefined>(value);
  const [loading, setLoading] = useState<boolean>(false);
  const { size, extent } = JSON.parse(materialClaimJson);
  /** 变量END */

  const beforeUpload = async (file: RcFile) => {
    console.log('file--->', file);
    const isZipOrRar = file.type === 'video/mp4';
    if (!isZipOrRar) {
      message.error('您只能上传MP4文件！');
    }
    const [minSize, maxSize] = extent;
    const fileSizeM = file.size / 1024 / 1024;
    const isLt20M = fileSizeM >= minSize && fileSizeM <= maxSize;
    if (!isLt20M) {
      message.error(`视频大小必须在${minSize}MB ~ ${maxSize}MB区间！`);
    }
    let videoInfo = await videoMessage([file]);
    const { width = 0, height = 0 } = videoInfo[0];
    const [w, h] = size;
    const isWHCorrect = Number(width) === Number(w) && Number(h) === Number(height);
    if (!isWHCorrect) {
      message.error(`视频宽高必须${w} * ${h}！`);
    }
    const md5 = await getMD5(file);
    const isRepeat =
      materialBeanList?.length > 0 ? !materialBeanList.some((item) => item.md5 === md5) : true;
    if (!isRepeat) {
      message.error(`请勿重复选择！`);
    }
    return isZipOrRar && isLt20M && isWHCorrect && isRepeat;
  };

  return (
    <div className="myUploadVideo">
      <Space align="start">
        <Upload.Dragger
          name="file"
          accept="video/mp4"
          className="avatar-uploader"
          beforeUpload={beforeUpload}
          maxCount={1}
          showUploadList={false}
          disabled={loading}
          customRequest={(options: any) => {
            setLoading(true);
            getOssInfo({ type: 'video/mp4', fileType: 'video' }).then(async (res) => {
              try {
                let formData = new FormData();
                Object.keys(res.data).forEach((key: string) => {
                  if (key !== 'url') {
                    formData.append(key, res.data[key]);
                  }
                });
                formData.append('file', options.file);
                const md5 = await getMD5(options.file);
                let urlData = await request(res?.data?.ossUrl, { method: 'POST', data: formData });
                setLoading(false);
                if (urlData?.data?.url) {
                  console.log('=====>', {
                    url: urlData?.data?.url,
                    size: options.file.size,
                    md5,
                  });
                  setVideoFile({
                    url: urlData?.data?.url,
                    size: options.file.size,
                    md5,
                  });
                  onChange?.({
                    url: urlData?.data?.url,
                    size: options.file.size,
                    md5,
                  });
                }
              } catch (error) {
                setLoading(false);
              }
            });
          }}
        >
          <Spin spinning={loading}>
            {videoFile?.url ? (
              <div className="video-content">
                <VideoNews src={videoFile?.url} />
              </div>
            ) : (
              <>
                <p className="ant-upload-drag-icon">
                  <InboxOutlined />
                </p>
                <p className="ant-upload-text">单击或拖动视频到此区域进行上传</p>
                <p className="ant-upload-hint" style={{ width: 450 }}>
                  素材要求：素材尺寸：{size?.[0]} * {size?.[1]}，素材大小：{extent?.[0]}MB ~{' '}
                  {extent?.[1]}MB（{extent?.[0] ? extent?.[0] * 1024 : extent?.[0]}KB ~{' '}
                  {extent?.[1] ? extent?.[1] * 1024 : extent?.[1]}KB）
                </p>
              </>
            )}
          </Spin>
        </Upload.Dragger>
      </Space>
    </div>
  );
};

export default React.memo(Video);
